package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/admin/md"
	svc2 "applet/app/admin/svc/enterprise_manage"
	md2 "applet/app/customer/md"
	"applet/app/customer/svc"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	"applet/app/enum"
	"applet/app/utils"
	"encoding/csv"
	"fmt"
	"github.com/360EntSecGroup-Skylar/excelize"
	"github.com/gin-gonic/gin"
	"net/http"
	"os"
	"strconv"
	"time"
)

func SelfSupportForSchoolUserUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolUserUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolUserUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolUserDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolUserDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolUserDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentList(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolStudentList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"admission_list": []map[string]string{
			{
				"name":  "按班级",
				"value": "admission_type_by_class",
			},
			{
				"name":  "按年级",
				"value": "admission_type_by_grade",
			},
		},
		"collect_face_type_list": []map[string]interface{}{
			{
				"name":  "个采",
				"value": 1,
			},
			{
				"name":  "集采",
				"value": 2,
			},
		},
		"user_identity_cert_type_list": []map[string]interface{}{
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForIdCard),
				"value": enum.UserIdentityCertTypeForIdCard,
			},
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForStudentId),
				"value": enum.UserIdentityCertTypeForStudentId,
			},
			//{
			//	"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForPassport),
			//	"value": enum.UserIdentityCertTypeForPassport,
			//},
		},
	}, nil)
	return
}

func SelfSupportForSchoolTeacherList(c *gin.Context) {
	var req md.SelfSupportForSchoolTeacherListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolTeacherList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"collect_face_type_list": []map[string]interface{}{
			{
				"name":  "个采",
				"value": 1,
			},
			{
				"name":  "集采",
				"value": 2,
			},
		},
		"user_identity_cert_type_list": []map[string]interface{}{
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForIdCard),
				"value": enum.UserIdentityCertTypeForIdCard,
			},
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForStudentId),
				"value": enum.UserIdentityCertTypeForStudentId,
			},
			//{
			//	"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForPassport),
			//	"value": enum.UserIdentityCertTypeForPassport,
			//},
		},
	}, nil)
	return
}

func SelfSupportForSchoolTeacherUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolTeacherUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if userIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	userIdentity.CertType = req.CertType
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name", "cert_type")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//更新 self_support_for_user_face_info
	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(req.UserIdentityId)
	info, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if info == nil {
		now := time.Now()
		selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
		selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
		selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
		if err != nil {
			return
		}
		if selfSupportForSchoolInfo == nil {
			e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
			return
		}
		info = &model.SelfSupportForUserFaceInfo{
			EnterpriseId:                    req.EnterpriseId,
			UserIdentityId:                  req.UserIdentityId,
			CollectFaceType:                 req.CollectFaceType,
			SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
			SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
			ParentUserId:                    "",
			ParentLogonId:                   "",
			UserId:                          "",
			SchoolFacePassStatus:            "CLOSE",
			SchoolFacePaymentStatus:         "CLOSE",
			ConcentrateSchoolFacePassStatus: 1,
			CreateAt:                        now.Format("2006-01-02 15:04:05"),
			UpdateAt:                        now.Format("2006-01-02 15:04:05"),
		}
		_, err1 := selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(info)
		if err1 != nil {
			e.OutErr(c, e.ERR, err1.Error())
			return
		}
	} else {
		info.CollectFaceType = req.CollectFaceType
		_, err = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoUpdate(info, "collect_face_type")
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc2.SelfSupportForSchoolStudentUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentAdmission(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentAdmissionReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolStudentAdmission(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolStudentDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.SelfSupportForSchoolStudentDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolTeacherDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolTeacherDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//删除 self_support_for_user_face_info
	_, err = db.Db.In("user_identity_id", req.UserIdentityIds).Delete(model.SelfSupportForUserFaceInfo{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolWorkerList(c *gin.Context) {
	var req md.SelfSupportForSchoolWorkerListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolWorkerList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"collect_face_type_list": []map[string]interface{}{
			{
				"name":  "个采",
				"value": 1,
			},
			{
				"name":  "集采",
				"value": 2,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolWorkerUpdate(c *gin.Context) {
	var req md.SelfSupportForSchoolWorkerUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if userIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolWorkerDelete(c *gin.Context) {
	var req md.SelfSupportForSchoolWorkerDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolGradeList(c *gin.Context) {
	var req md.SelfSupportForSchoolGradeListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolGradeList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func SelfSupportForSchoolClassList(c *gin.Context) {
	var req md.SelfSupportForSchoolClassListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolClassList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func SelfSupportForSchoolGradeDelete(c *gin.Context) {
	gradeId := c.Param("id")
	//1、查找当前年级
	gradeDb := db.GradeDb{}
	gradeDb.Set(0)
	grade, err := gradeDb.GetGrade(utils.StrToInt(gradeId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、查找当前年级下是否还包含班级
	classDb := db.ClassDb{}
	classDb.Set(grade.Id)
	class, err := classDb.FindClass()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if len(*class) > 0 {
		e.OutErr(c, e.ERR_FORBIDEN, "当前年级下存在未删除的班级!")
		return
	}
	_, err = gradeDb.GradeDeleteBySession(grade.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolClassDelete(c *gin.Context) {
	classId := c.Param("id")
	//1、查找当前年级
	classDb := db.ClassDb{}
	classDb.Set(0)
	class, err := classDb.GetClass(utils.StrToInt(classId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	_, err = classDb.ClassDeleteBySession(class.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、删除当前班级下的所有关联学生
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	_, err = classWithUserDb.DeleteClassWithUserByClass(classId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolClassDeleteCheck(c *gin.Context) {
	classId := c.Param("id")
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	classWithUsers, err := classWithUserDb.FindUserIdentity(classId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var isHasStudent = false
	if len(*classWithUsers) > 0 {
		isHasStudent = true
	}

	e.OutSuc(c, map[string]interface{}{
		"is_has_student": isHasStudent,
	}, nil)
	return
}

func SelfSupportForSchoolAddWorker(c *gin.Context) {
	var req md.SelfSupportForSchoolAddWorkerReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//1、查找当前身份是否已存在
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	isHasUserIdentity, err := userIdentityDb.UserIdentityExist(req.EnterpriseId, req.IdNo, enum.UserIdentityCertTypeForIdCard)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if isHasUserIdentity != nil {
		e.OutErr(c, e.ERR, "当前身份已存在,直接修改身份即可!")
		return
	}

	now := time.Now()
	//2、新增身份信息
	userIdentity := &model.UserIdentity{
		Uid:          0,
		Name:         req.Name,
		IdNo:         req.IdNo,
		CertType:     enum.UserIdentityCertTypeForIdCard,
		Kind:         enum.UserIdentityKindForWorker,
		Identity:     enum.UserIdentityForSelfSupportForWorker,
		EnterpriseId: req.EnterpriseId,
		State:        enum.UserIdentityStateForNormal,
		Memo:         "",
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	}
	insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if insertAffected <= 0 {
		e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolAddTeacher(c *gin.Context) {
	var req md.SelfSupportForSchoolAddTeacherReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//1、查找当前身份是否已存在
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	isHasUserIdentity, err := userIdentityDb.UserIdentityExist(req.EnterpriseId, req.IdNo, req.CertType)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if isHasUserIdentity != nil {
		e.OutErr(c, e.ERR, "当前身份已存在,直接修改身份即可!")
		return
	}

	now := time.Now()
	//2、新增身份信息
	userIdentity := &model.UserIdentity{
		Uid:          0,
		Name:         req.Name,
		IdNo:         req.IdNo,
		CertType:     req.CertType,
		Kind:         enum.UserIdentityKindForCommon,
		Identity:     enum.UserIdentityForSelfSupportForTeacher,
		EnterpriseId: req.EnterpriseId,
		State:        enum.UserIdentityStateForNormal,
		Memo:         "",
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	}
	insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if insertAffected <= 0 {
		e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
		return
	}

	//更新 self_support_for_user_face_info
	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(insertAffected)
	info, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if info == nil {
		selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
		selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
		selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
		if err != nil {
			return
		}
		if selfSupportForSchoolInfo == nil {
			e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
			return
		}
		info = &model.SelfSupportForUserFaceInfo{
			EnterpriseId:                    req.EnterpriseId,
			UserIdentityId:                  insertAffected,
			CollectFaceType:                 1, //教师都是个采
			SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
			SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
			ParentUserId:                    "",
			ParentLogonId:                   "",
			UserId:                          "",
			SchoolFacePassStatus:            "CLOSE",
			SchoolFacePaymentStatus:         "CLOSE",
			ConcentrateSchoolFacePassStatus: 1,
			CreateAt:                        now.Format("2006-01-02 15:04:05"),
			UpdateAt:                        now.Format("2006-01-02 15:04:05"),
		}
		_, err1 := selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(info)
		if err1 != nil {
			e.OutErr(c, e.ERR, err1.Error())
			return
		}
	} else {
		info.CollectFaceType = 1
		_, err = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoUpdate(info, "collect_face_type")
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolAddStudent(c *gin.Context) {
	var req md.SelfSupportForSchoolStudentAddReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	//1、查找当前身份是否已存在
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	isHasUserIdentity, err := userIdentityDb.UserIdentityExist(req.EnterpriseId, req.IdNo, req.CertType)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if isHasUserIdentity != nil {
		e.OutErr(c, e.ERR, "当前身份已存在,直接修改身份即可!")
		return
	}

	now := time.Now()
	//2、新增身份信息
	userIdentity := &model.UserIdentity{
		Uid:          0,
		Name:         req.Name,
		IdNo:         req.IdNo,
		CertType:     req.CertType,
		Kind:         enum.UserIdentityKindForCommon,
		Identity:     enum.UserIdentityForSelfSupportForStudent,
		EnterpriseId: req.EnterpriseId,
		State:        enum.UserIdentityStateForNormal,
		Memo:         "",
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	}
	insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if insertAffected <= 0 {
		e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
		return
	}

	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	_, err = classWithUserDb.ClassWithUserInsert(&model.ClassWithUser{
		UserIdentityId: insertAffected,
		ClassId:        req.ClassId,
		CreateAt:       now.Format("2006-01-02 15:04:05"),
		UpdateAt:       now.Format("2006-01-02 15:04:05"),
	})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//更新 self_support_for_user_face_info
	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(insertAffected)
	info, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if info == nil {
		selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
		selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
		selfSupportForSchoolInfo, err1 := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		if selfSupportForSchoolInfo == nil {
			e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
			return
		}
		info = &model.SelfSupportForUserFaceInfo{
			EnterpriseId:                    req.EnterpriseId,
			UserIdentityId:                  insertAffected,
			CollectFaceType:                 req.CollectFaceType, //教师都是个采
			SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
			SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
			ParentUserId:                    "",
			ParentLogonId:                   "",
			UserId:                          "",
			SchoolFacePassStatus:            "CLOSE",
			SchoolFacePaymentStatus:         "CLOSE",
			ConcentrateSchoolFacePassStatus: 1,
			CreateAt:                        now.Format("2006-01-02 15:04:05"),
			UpdateAt:                        now.Format("2006-01-02 15:04:05"),
		}
		_, err1 = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(info)
		if err1 != nil {
			e.OutErr(c, e.ERR, err1.Error())
			return
		}
	} else {
		info.CollectFaceType = req.CollectFaceType
		_, err = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoUpdate(info, "collect_face_type")
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolImportTeacher(c *gin.Context) {
	enterpriseIdStr := c.DefaultQuery("enterprise_id", "")
	enterpriseId := utils.StrToInt(enterpriseIdStr)
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(enterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	files, _ := c.FormFile("file")
	dst := "./static/upload/" + files.Filename
	err = c.SaveUploadedFile(files, dst)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	xlsx, err := excelize.OpenFile(dst)
	rows := xlsx.GetRows("Sheet" + "1")
	for key, row := range rows {
		if key > 0 && (row[0] != "" && row[1] != "") {
			idNo := row[0]
			name := row[1]
			//1、查找当前身份是否已存在
			userIdentityDb := db.UserIdentityDb{}
			userIdentityDb.Set(0)
			isHasUserIdentity, err := userIdentityDb.UserIdentityExist(enterpriseId, idNo, enum.UserIdentityCertTypeForIdCard)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if isHasUserIdentity != nil {
				continue
			}

			now := time.Now()
			//2、新增身份信息
			userIdentity := &model.UserIdentity{
				Uid:          0,
				Name:         name,
				IdNo:         idNo,
				CertType:     enum.UserIdentityCertTypeForIdCard,
				Kind:         enum.UserIdentityKindForCommon,
				Identity:     enum.UserIdentityForSelfSupportForTeacher,
				EnterpriseId: enterpriseId,
				State:        enum.UserIdentityStateForNormal,
				Memo:         "",
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			}
			insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if insertAffected <= 0 {
				e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
				return
			}

			//更新 self_support_for_user_face_info
			selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
			selfSupportForUserFaceInfoDb.Set(insertAffected)
			info, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if info == nil {
				selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
				selfSupportForSchoolInfoDb.Set(enterpriseId)
				selfSupportForSchoolInfo, err1 := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
				if err1 != nil {
					e.OutErr(c, e.ERR_DB_ORM, err.Error())
					return
				}
				if selfSupportForSchoolInfo == nil {
					e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
					return
				}
				info = &model.SelfSupportForUserFaceInfo{
					EnterpriseId:                    enterpriseId,
					UserIdentityId:                  insertAffected,
					CollectFaceType:                 1, //教师都是个采
					SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
					SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
					ParentUserId:                    "",
					ParentLogonId:                   "",
					UserId:                          "",
					SchoolFacePassStatus:            "CLOSE",
					SchoolFacePaymentStatus:         "CLOSE",
					ConcentrateSchoolFacePassStatus: 1,
					CreateAt:                        now.Format("2006-01-02 15:04:05"),
					UpdateAt:                        now.Format("2006-01-02 15:04:05"),
				}
				_, err1 = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(info)
				if err1 != nil {
					e.OutErr(c, e.ERR, err1.Error())
					return
				}
			} else {
				info.CollectFaceType = 1
				_, err1 := selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoUpdate(info, "collect_face_type")
				if err1 != nil {
					e.OutErr(c, e.ERR_DB_ORM, err1.Error())
					return
				}
			}
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func ImportV2(c *gin.Context) {
	f, err := os.OpenFile("./static/template/alipay.csv", os.O_RDWR, 0666)
	if err != nil {
		fmt.Println("Error: ", err)
		return
	}
	writer := csv.NewWriter(f)

	//bytesBuffer := &bytes.Buffer{}
	//bytesBuffer.WriteString("\xEF\xBB\xBF") //写入UTF-8 BOM,此处如果不写入就会导致写入的汉字乱码
	//writer := csv.NewWriter(bytesBuffer)
	writer.Write([]string{"支付宝批量付款文件模板"})
	writer.Write([]string{"序号（必填）", "收款方支付宝账号（必填）", "收款方姓名（必填）", "金额（必填，单位：元）", "备注（选填）"})

	for i := 2; i <= 2; i++ {
		writer.Write([]string{utils.IntToStr(i - 1), "1239118001@qq.com", "邓彪", "1.11", "测试"})
	}

	writer.Flush()                                                                 // 此时才会将缓冲区数据写入
	c.Writer.Header().Set("Content-Disposition", "attachment;filename=alipay.csv") // 设置下载的文件名
	file, err := os.ReadFile("./static/template/alipay.csv")
	if err != nil {
		fmt.Println("Error: ", err)
		return
	}
	c.Data(http.StatusOK, "text/csv", file) // 设置文件类型以及输出数据
	return
}

func SelfSupportForSchoolDownloadTemplateExcel(c *gin.Context) {
	e.OutSuc(c, "/template/自营学校(教师信息导入模板).xls", nil)
	return
}

func SelfSupportForSchoolOrdList(c *gin.Context) {
	var req md.SelfSupportForSchoolOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolOrdList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":                 resp,
		"total":                total,
		"enterprise_kind_list": md.EnterpriseKindForSchool,
		"order_status_list": []map[string]interface{}{
			{
				"name":  enum.SelfSupportForSchoolOrdOrderStatus.String(enum.SelfSupportForSchoolOrdOrderStatusForWait),
				"value": enum.SelfSupportForSchoolOrdOrderStatusForWait,
			},
			{
				"name":  enum.SelfSupportForSchoolOrdOrderStatus.String(enum.SelfSupportForSchoolOrdOrderStatusForSuccess),
				"value": enum.SelfSupportForSchoolOrdOrderStatusForSuccess,
			},
		},
	}, nil)
	return
}

func SelfSupportForSchoolConsumeLimit(c *gin.Context) {
	var req []*md.SelfSupportForSchoolConsumeLimitReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", ""))
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(enterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应校企记录")
		return
	}
	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(enterpriseId)
	selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		return
	}
	if selfSupportForSchoolInfo == nil {
		e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
		return
	}

	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	userIdentityDb := db.UserIdentityDb{}
	var data md2.CurlAlipayPlanetEcocampusApiRosterConsumeLimit
	var mm []*model.SelfSupportForUserConsumeLimit
	var userIdentityIds []int
	now := time.Now()
	for _, v := range req {
		selfSupportForUserFaceInfoDb.Set(v.UserIdentityId)
		userIdentityDb.Set(0)
		faceInfo, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if faceInfo == nil {
			e.OutErr(c, e.ERR_NO_DATA, "用户【"+utils.IntToStr(v.UserIdentityId)+"】身份未查询到一脸通行相关数据")
			return
		}
		identity, err := userIdentityDb.GetUserIdentity(v.UserIdentityId)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if identity == nil {
			e.OutErr(c, e.ERR_NO_DATA, "用户【"+utils.IntToStr(v.UserIdentityId)+"】身份未查询到")
			return
		}

		data.SchoolCode = selfSupportForSchoolInfo.SchoolCode
		data.SchoolName = selfSupportForSchoolInfo.SchoolName
		data.ConsumeLimitSyncInfo = append(data.ConsumeLimitSyncInfo, md2.ConsumeLimitSyncInfo{
			FaceUid:                  faceInfo.UserId,
			OutRosterCode:            utils.IntToStr(v.UserIdentityId),
			RosterName:               identity.Name,
			DailyConsumeLimit:        v.DailyConsumeLimit,
			DailyConsumeLimitSwitch:  v.DailyConsumeLimitSwitch,
			SingleConsumeLimit:       v.SingleConsumeLimit,
			SingleConsumeLimitSwitch: v.SingleConsumeLimitSwitch,
			DailyConsumeNumber:       v.DailyConsumeNumber,
			DailyConsumeNumberSwitch: v.DailyConsumeNumberSwitch,
		})
		mm = append(mm, &model.SelfSupportForUserConsumeLimit{
			EnterpriseId:             enterpriseId,
			UserIdentityId:           v.UserIdentityId,
			DailyConsumeLimit:        v.DailyConsumeLimit,
			DailyConsumeLimitSwitch:  v.DailyConsumeLimitSwitch,
			SingleConsumeLimit:       v.SingleConsumeLimit,
			SingleConsumeLimitSwitch: v.SingleConsumeLimitSwitch,
			DailyConsumeNumber:       v.DailyConsumeNumber,
			DailyConsumeNumberSwitch: v.DailyConsumeNumberSwitch,
			CreateAt:                 now.Format("2006-01-02 15:04:05"),
			UpdateAt:                 now.Format("2006-01-02 15:04:05"),
		})
		userIdentityIds = append(userIdentityIds, v.UserIdentityId)
	}

	err, resp := svc.CurlAlipayPlanetEcocampusApiRosterConsumeLimit(data)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	//TODO::记录到表中
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.SelfSupportForUserConsumeLimit{})
	if err != nil {
		return
	}
	selfSupportForUserConsumeLimitDb := db.SelfSupportForUserConsumeLimitDb{}
	selfSupportForUserConsumeLimitDb.Set(0)
	_, err = selfSupportForUserConsumeLimitDb.BatchAdd(mm)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, resp, nil)
	return
}

func SelfSupportForSchoolConsumeLimitList(c *gin.Context) {
	var req md.SelfSupportForSchoolConsumeLimitListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			e.OutErr(c, e.ERR, err2.Error())
			return
		}

		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			e.OutErr(c, e.ERR, err3.Error())
			return
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			e.OutErr(c, e.ERR, err4.Error())
			return
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}
	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).
		Desc("self_support_for_user_consume_limit.id")
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess.And("user_identity.identity =?", enum.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess.And("user_identity.identity !=?", enum.UserIdentityForCentralKitchenForTeacher)
		}
	}
	if req.DailyConsumeLimit != "" {
		sess.And("self_support_for_user_consume_limit.daily_consume_limit = ?", req.DailyConsumeLimit)
	}
	if req.DailyConsumeLimitSwitch != "" {
		sess.And("self_support_for_user_consume_limit.daily_consume_limit_switch = ?", req.DailyConsumeLimitSwitch)
	}
	if req.SingleConsumeLimit != "" {
		sess.And("self_support_for_user_consume_limit.single_consume_limit = ?", req.SingleConsumeLimit)
	}
	if req.SingleConsumeLimitSwitch != "" {
		sess.And("self_support_for_user_consume_limit.single_consume_limit_switch = ?", req.SingleConsumeLimitSwitch)
	}
	if req.DailyConsumeNumber != "" {
		sess.And("self_support_for_user_consume_limit.daily_consume_number = ?", req.DailyConsumeNumber)
	}
	if req.DailyConsumeNumberSwitch != "" {
		sess.And("self_support_for_user_consume_limit.daily_consume_number_switch = ?", req.DailyConsumeNumberSwitch)
	}
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.SelfSupportForUserConsumeLimitWithUserIdentity
	count, err := sess.
		Join("LEFT", "self_support_for_user_consume_limit", "user_identity.id = self_support_for_user_consume_limit.user_identity_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	var list []md.SelfSupportForSchoolConsumeLimitListResp
	for _, v := range m {
		var dailyConsumeLimitSwitch, singleConsumeLimitSwitch, dailyConsumeNumberSwitch = "off", "off", "off"
		if v.SelfSupportForUserConsumeLimit.DailyConsumeLimitSwitch != "" {
			dailyConsumeLimitSwitch = v.SelfSupportForUserConsumeLimit.DailyConsumeLimitSwitch
		}
		if v.SelfSupportForUserConsumeLimit.SingleConsumeLimitSwitch != "" {
			singleConsumeLimitSwitch = v.SelfSupportForUserConsumeLimit.SingleConsumeLimitSwitch
		}
		if v.SelfSupportForUserConsumeLimit.DailyConsumeNumberSwitch != "" {
			dailyConsumeNumberSwitch = v.SelfSupportForUserConsumeLimit.DailyConsumeNumberSwitch
		}

		list = append(list, md.SelfSupportForSchoolConsumeLimitListResp{
			UserIdentityId:           v.UserIdentity.Id,
			Name:                     v.UserIdentity.Name,
			GradeId:                  v.Grade.Id,
			GradeName:                v.Grade.Name,
			ClassId:                  v.Class.Id,
			ClassName:                v.Class.Name,
			Phone:                    v.User.Phone,
			DailyConsumeLimit:        v.SelfSupportForUserConsumeLimit.DailyConsumeLimit,
			DailyConsumeLimitSwitch:  dailyConsumeLimitSwitch,
			SingleConsumeLimit:       v.SelfSupportForUserConsumeLimit.SingleConsumeLimit,
			SingleConsumeLimitSwitch: singleConsumeLimitSwitch,
			DailyConsumeNumber:       v.SelfSupportForUserConsumeLimit.DailyConsumeNumber,
			DailyConsumeNumberSwitch: dailyConsumeNumberSwitch,
		})
	}
	e.OutSuc(c, map[string]interface{}{
		"list":                 list,
		"enterprise_kind_list": md.EnterpriseKindForSchool,
		"daily_consume_limit_switch_list": []map[string]string{
			{
				"name":  "开启",
				"value": "on",
			},
			{
				"name":  "关闭",
				"value": "off",
			},
		},
		"single_consume_limit_switch_list": []map[string]string{
			{
				"name":  "开启",
				"value": "on",
			},
			{
				"name":  "关闭",
				"value": "off",
			},
		},
		"daily_consume_number_switch_list": []map[string]string{
			{
				"name":  "开启",
				"value": "on",
			},
			{
				"name":  "关闭",
				"value": "off",
			},
		},
		"total": count,
	}, nil)
	return
}

func SelfSupportForSchoolOrdListExport(c *gin.Context) {
	var req md.SelfSupportForSchoolOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, err := svc2.SelfSupportForSchoolOrdListExport(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	titleList := []string{"订单编号", "支付交易号", "家长电话", "就餐人姓名", "学校名称", "年级", "班级", "总金额", "支付状态", "就餐时间", "设备编号", "消费档口"}
	xlsx := excelize.NewFile()
	xlsx.SetSheetRow("Sheet1", "A1", &titleList)
	//表头被第一行用了，只能从第二行开始
	j := 2
	var totalAmount = 0.00
	for _, v := range resp {
		stateName := "支付成功"
		if v.OrderStatus == 1 {
			stateName = "待支付"
		}
		totalAmount += utils.StrToFloat64(v.TotalPrice)
		xlsx.SetSheetRow("Sheet1", "A"+strconv.Itoa(j), &[]interface{}{v.OutTradeNo, v.TradeNo, v.Phone, v.Name, v.EnterpriseName, v.Class, v.Grade, v.TotalPrice, stateName, v.FaceTime, v.DeviceSn, v.ShopName})
		j++
	}

	xlsx.SetSheetRow("Sheet1", "A"+strconv.Itoa(j), &[]interface{}{"总计：", "-", "-", "-", "-", "-", "-", totalAmount, "-", "-", "-", "-"})

	c.Header("Content-Type", "application/octet-stream")
	c.Header("Content-Disposition", "attachment; filename="+"消费记录"+".xlsx")
	c.Header("Content-Transfer-Encoding", "binary")
	//回写到web 流媒体 形成下载
	_ = xlsx.Write(c.Writer)
	return
}

func SelfSupportForSchoolArrearsOrdList(c *gin.Context) {
	var req md.SelfSupportForSchoolArrearsOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.SelfSupportForSchoolArrearsOrdList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":                 resp,
		"enterprise_kind_list": md.EnterpriseKindForSchool,
		"total":                total,
	}, nil)
	return
}

func SelfSupportForSchoolBlackList(c *gin.Context) {
	var req md.SelfSupportForSchoolBlackListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
	info, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if info == nil {
		e.OutErr(c, e.ERR, "当前学校暂未完成《一脸通行入驻》")
		return
	}

	err, resp := svc.CurlAlipayPlanetEcocampusApiRosterPageQueryBlackList(md2.CurlAlipayPlanetEcocampusApiRosterPageQueryBlackList{
		SchoolCode: info.SchoolCode,
		PageNo:     req.Page,
		PageSize:   req.Limit,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, resp, nil)
	return
}

func SelfSupportForSchoolArrearsOrdDebtRepay(c *gin.Context) {
	var req md.SelfSupportForSchoolArrearsOrdDebtRepayReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err, resp := svc.CurlSelfSupportForSchoolOrderDebtRepay(md2.CurlSelfSupportForSchoolOrderDebtRepay{
		OutOrderNo:   req.OutOrderNo,
		MerchantCode: req.MerchantCode,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, resp, nil)
	return
}

func SelfSupportForSchoolArrearsOrdDebtCancel(c *gin.Context) {
	var req md.SelfSupportForSchoolArrearsOrdDebtCancelReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err, resp := svc.CurlAlipayPlanetEcocampusApiDebtCancel(md2.CurlAlipayPlanetEcocampusApiDebtCancel{
		OutOrderNo:   req.OutOrderNo,
		MerchantCode: req.MerchantCode,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, resp, nil)
	return
}

func SelfSupportForSchoolEducateSceneKidsClose(c *gin.Context) {
	userIdentityId := c.DefaultQuery("user_identity_id", "")
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	identity, err := userIdentityDb.GetUserIdentity(utils.StrToInt(userIdentityId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(identity.EnterpriseId)
	selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if selfSupportForSchoolInfo == nil {
		e.OutErr(c, e.ERR_NO_DATA, "当前学校暂未完成《一脸通行入驻》")
		return
	}

	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(identity.Id)
	selfSupportForUserFaceInfo, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	var certType string
	switch identity.CertType {
	case enum.UserIdentityCertTypeForIdCard:
		certType = "1"
	case enum.UserIdentityCertTypeForStudentId:
		certType = "X"
	case enum.UserIdentityCertTypeForPassport:
		certType = "A"
	}
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.OpenAppletAppid, enum.OpenAppletAppPrivateKey, enum.OpenAppletPublicKey)
	err, info := svc.CurlEducateSceneKidsClose(md2.CurlEducateSceneKidsCloseReq{
		Config: struct {
			AliAppId      string `json:"ali_app_id" label:"支付宝开放平台-小程序-appid"`
			AliPrivateKey string `json:"ali_private_key" label:"支付宝开放平台-小程序-应用私钥"`
			AliPublicKey  string `json:"ali_public_key" label:"支付宝开放平台-小程序-支付宝公钥"`
		}{
			AliAppId:      sysCfg[enum.OpenAppletAppid],
			AliPrivateKey: sysCfg[enum.OpenAppletAppPrivateKey],
			AliPublicKey:  sysCfg[enum.OpenAppletPublicKey],
		},
		CertType:      certType,
		CertNo:        identity.IdNo,
		SchoolStdCode: selfSupportForSchoolInfo.SchoolStdCode,
		ParentUid:     selfSupportForUserFaceInfo.ParentUserId,
		UserId:        selfSupportForUserFaceInfo.UserId,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, info, nil)
	return
}

func SelfSupportForSchoolEducateFacepayClose(c *gin.Context) {
	userIdentityId := c.DefaultQuery("user_identity_id", "")
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	identity, err := userIdentityDb.GetUserIdentity(utils.StrToInt(userIdentityId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(identity.EnterpriseId)
	selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if selfSupportForSchoolInfo == nil {
		e.OutErr(c, e.ERR_NO_DATA, "当前学校暂未完成《一脸通行入驻》")
		return
	}

	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(identity.Id)
	selfSupportForUserFaceInfo, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.OpenAppletAppid, enum.OpenAppletAppPrivateKey, enum.OpenAppletPublicKey)
	err, info := svc.CurlEducateFacepayClose(md2.CurlEducateFacepayCloseReq{
		Config: struct {
			AliAppId      string `json:"ali_app_id" label:"支付宝开放平台-小程序-appid"`
			AliPrivateKey string `json:"ali_private_key" label:"支付宝开放平台-小程序-应用私钥"`
			AliPublicKey  string `json:"ali_public_key" label:"支付宝开放平台-小程序-支付宝公钥"`
		}{
			AliAppId:      sysCfg[enum.OpenAppletAppid],
			AliPrivateKey: sysCfg[enum.OpenAppletAppPrivateKey],
			AliPublicKey:  sysCfg[enum.OpenAppletPublicKey],
		},
		SchoolStdCode: selfSupportForSchoolInfo.SchoolStdCode,
		FaceUid:       selfSupportForUserFaceInfo.UserId,
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, info, nil)
	return
}
