package db

import (
	"applet/app/db/model"
	"applet/app/utils/logx"
	"reflect"
	"xorm.io/xorm"
)

type SelfSupportForUserFaceInfoDb struct {
	Db             *xorm.Engine `json:"db"`
	UserIdentityId int          `json:"user_identity_id"`
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) Set(userIdentityId int) { // set方法
	selfSupportForUserFaceInfoDb.Db = Db
	selfSupportForUserFaceInfoDb.UserIdentityId = userIdentityId
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) GetSelfSupportForUserFaceInfo() (m *model.SelfSupportForUserFaceInfo, err error) {
	m = new(model.SelfSupportForUserFaceInfo)
	has, err := selfSupportForUserFaceInfoDb.Db.Where("user_identity_id =?", selfSupportForUserFaceInfoDb.UserIdentityId).Get(m)
	if err != nil {
		return nil, logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) FindSelfSupportForUserFaceInfo(limit, start int) (*[]model.SelfSupportForUserFaceInfo, error) {
	var m []model.SelfSupportForUserFaceInfo
	if limit == 0 || start == 0 {
		if err := selfSupportForUserFaceInfoDb.Db.Desc("id").Find(&m); err != nil {
			return nil, logx.Error(err)
		}
	} else {
		if err := selfSupportForUserFaceInfoDb.Db.Desc("id").Limit(limit, start).Find(m); err != nil {
			return nil, logx.Error(err)
		}
	}
	return &m, nil
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) GetSelfSupportForUserFaceInfoByName(name string) (m *model.SelfSupportForUserFaceInfo, err error) {
	m = new(model.SelfSupportForUserFaceInfo)
	has, err := selfSupportForUserFaceInfoDb.Db.Where("name =?", name).Get(m)
	if err != nil {
		return nil, logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) SelfSupportForUserFaceInfoInsert(m *model.SelfSupportForUserFaceInfo) (int, error) {
	_, err := selfSupportForUserFaceInfoDb.Db.InsertOne(m)
	if err != nil {
		return 0, err
	}
	return m.Id, nil
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) SelfSupportForUserFaceInfoUpdate(m *model.SelfSupportForUserFaceInfo, columns ...string) (int64, error) {
	affected, err := selfSupportForUserFaceInfoDb.Db.Where("id =?", m.Id).Cols(columns...).Update(m)
	if err != nil {
		return 0, err
	}
	return affected, nil
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) SelfSupportForUserFaceInfoDelete(id interface{}) (int64, error) {
	if reflect.TypeOf(id).Kind() == reflect.Slice {
		return Db.In("id", id).Delete(model.SelfSupportForUserFaceInfo{})
	} else {
		return Db.Where("id = ?", id).Delete(model.SelfSupportForUserFaceInfo{})
	}
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) CountSchoolFacePassStatus(enterpriseId int, status string) (total int64, err error) {
	var m model.SelfSupportForUserFaceInfo
	total, err = selfSupportForUserFaceInfoDb.Db.Where("enterprise_id =? AND school_face_pass_status =?", enterpriseId, status).Count(&m)
	if err != nil {
		return
	}
	return
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) CountSchoolFacePaymentStatus(enterpriseId int, status string) (total int64, err error) {
	var m model.SelfSupportForUserFaceInfo
	total, err = selfSupportForUserFaceInfoDb.Db.Where("enterprise_id =? AND concentrate_school_face_pass_status =?", enterpriseId, status).Count(&m)
	if err != nil {
		return
	}
	return
}

func (selfSupportForUserFaceInfoDb *SelfSupportForUserFaceInfoDb) CountCollectFaceType(enterpriseId, collectFaceType int) (total int64, err error) {
	var m model.SelfSupportForUserFaceInfo
	total, err = selfSupportForUserFaceInfoDb.Db.Where("enterprise_id =? AND collect_face_type =?", enterpriseId, collectFaceType).Count(&m)
	if err != nil {
		return
	}
	return
}

type SelfSupportForUserFaceInfoWithUserIdentity struct {
	model.SelfSupportForUserFaceInfo `xorm:"extends"`
	model.UserIdentity               `xorm:"extends"`
}

func (SelfSupportForUserFaceInfoWithUserIdentity) TableName() string {
	return "self_support_for_user_face_info"
}
